summaryrefslogtreecommitdiff
path: root/mpn/a29k/addmul_1.s
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/a29k/addmul_1.s')
-rw-r--r--mpn/a29k/addmul_1.s6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpn/a29k/addmul_1.s b/mpn/a29k/addmul_1.s
index 8c0ec96ce..f21ef2622 100644
--- a/mpn/a29k/addmul_1.s
+++ b/mpn/a29k/addmul_1.s
@@ -1,4 +1,4 @@
; 29000 __mpn_addmul_1 -- Multiply a limb vector with a single limb and
; add the product to a second limb vector.
; Copyright (C) 1992, 1994 Free Software Foundation, Inc.
@@ -31,9 +31,9 @@
.sect .lit,lit
.text
.align 4
- .global ___mpn_addmul_1
+ .global ___gmpn_addmul_1
.word 0x60000
-___mpn_addmul_1:
+___gmpn_addmul_1:
sub lr4,lr4,8
jmpt lr4,Ltail
const gr120,0 ; init cylimb reg
@@ -1,4 +1,4 @@
-; 29000 __mpn_addmul_1 -- Multiply a limb vector with a single limb and
+; 29000 __gmpn_addmul_1 -- Multiply a limb vector with a single limb and
; add the product to a second limb vector.
; Copyright (C) 1992, 1994 Free Software Foundation, Inc.